---
layout: page
page:
    aside: false      
mode: immersivebg
pagetitle: NLP & LLM Learning Hub - John Snow Labs
title: The NLP Learning Hub
excerpt: Enhance your AI, NLP, and LLM knowledge with materials prepared by domain experts on topics including Healthcare AI, Responsible AI, No-Code AI, Large Language Models, and Multimodal AI.
seotitle: NLP & LLM Learning Hub - John Snow Labs
permalink: /learn
show_subtitle: false
key: videos
license: false
show_date: true
modify_date: "2019-05-16"
---

<div class="grid--container learn-hub container">
    <div class="grid">
        <div class="cell cell--12 cell--lg-4 cell--sm-4">
            <div class="learn-hub-inner">
                <h4>The Technology</h4>
                <ul class="learn-hub-list">
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/spark-nlp-blog/">Spark NLP</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/healthcare-nlp-blog/">Healthcare NLP</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/visual-nlp-blog/">Spark OCR</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/annotation-lab-blog/">NLP Lab</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/auto-nlp-blog/">Auto NLP</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/multimodal-ai-blog/">Multimodal AI</a></li>
                </ul>
            </div>
        </div>
        <div class="cell cell--12 cell--lg-4 cell--sm-4">
            <div class="learn-hub-inner">
                <h4>The Technology in Action</h4>
                <ul class="learn-hub-list">
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/medical-ai-applications-blog/">Medical AI Applications</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/finance-ai-applications-blog/">Finance AI Applications</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/de-identification-blog/">De-Identification</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/multilingual-nlp-blog/">Multilingual NLP</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/nlp-on-databricks-blog/">NLP on Databricks</a></li>
                </ul>
            </div>
        </div>
        <div class="cell cell--12 cell--lg-4 cell--sm-4">
            <div class="learn-hub-inner">
                <h4>Industry Trends</h4>
                <ul class="learn-hub-list">
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/ai-in-healthcare-blog/">AI in Healthcare</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/no-code-ai-blog/">No-Code AI</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/responsible-nlp-blog/">Responsible NLP</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/data-philanthropy-blog/">Data Philanthropy</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/announcements-blog/">Announcements</a></li>
                    <li><a target="_blank" href="https://www.johnsnowlabs.com/awards-blog/">Awards</a></li>
                </ul>
            </div>
        </div>
    </div>
</div>
<div class="dn">
  <!-- HTML elements for search -->
  <input type="text" id="search-input" placeholder="Search...">
  <ul id="results-container" class="shadow results-container"></ul>
</div> 